voca.plugins package
====================

Submodules
----------

voca.plugins.basic module
-------------------------

.. automodule:: voca.plugins.basic
    :members:
    :undoc-members:
    :show-inheritance:

voca.plugins.math module
------------------------

.. automodule:: voca.plugins.math
    :members:
    :undoc-members:
    :show-inheritance:

voca.plugins.no module
----------------------

.. automodule:: voca.plugins.no
    :members:
    :undoc-members:
    :show-inheritance:

voca.plugins.python module
--------------------------

.. automodule:: voca.plugins.python
    :members:
    :undoc-members:
    :show-inheritance:

voca.plugins.stopstart module
-----------------------------

.. automodule:: voca.plugins.stopstart
    :members:
    :undoc-members:
    :show-inheritance:

voca.plugins.terminator module
------------------------------

.. automodule:: voca.plugins.terminator
    :members:
    :undoc-members:
    :show-inheritance:

voca.plugins.turtle\_context module
-----------------------------------

.. automodule:: voca.plugins.turtle_context
    :members:
    :undoc-members:
    :show-inheritance:

voca.plugins.yes module
-----------------------

.. automodule:: voca.plugins.yes
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: voca.plugins
    :members:
    :undoc-members:
    :show-inheritance:
